==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/ts/Draw_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Rysuj
&amp;Preferencje bieżącego rysunku</translatorcomment>
        <translation type="unfinished">&amp;Rysuj</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+63"/>
        <source>First corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/ts/Draw_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation>Rysowanie</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Rysuj
&amp;Preferencje bieżącego rysunku</translatorcomment>
        <translation>&amp;Rysowanie</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Drawing Tools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+69"/>
        <source>First corner</source>
        <translation>Pierwszy narożnik</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation>Drugi narożnik</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation>Górny lewy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation>Górny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation>Górny prawy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation>Lewy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Środkowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Prawy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation>Dolny lewy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Dolny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation>Dolny prawy</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation>Położenie</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation>Pierwszy łuk lub okrąg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation>Drugi łuk lub okrąg</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation>Trzeci łuk lub okrąg</translation>
    </message>
</context>
</TS>
